@@ -4,6 +4,7 @@ from pathlib import Path
 from typing import Any, Dict, List, Optional, Set, Union,TYPE_CHECKING
 from pyvisflow.core.components.containers import BoxContainer, Component
 from pyvisflow.core.components import DataTable, EChart
+from pyvisflow.core.components.plotly import Plotly
 from pyvisflow.core.dataManager import DataFrameManager
 from pyvisflow.core.props.fns import Fns
 from pyvisflow.core.structure import Mapping, Structure
@@ -98,6 +99,8 @@ class App(BoxContainer):
                 tableInfos.extend(cp._filter_watch_infos)
             if isinstance(cp, EChart):
                 chartInfos.extend(cp._filter_watch_infos)
+            if isinstance(cp, Plotly):
+                chartInfos.extend(cp._filter_watch_infos)
 
         for s in self.structures:
             valueInfos.extend(s._get_WatchInfos())
