@@ -1,3 +1,4 @@
+import base64
 from datetime import datetime
 from pathlib import Path
 from json import JSONEncoder, dumps
@@ -22,9 +23,6 @@ def get_project_root():
 
 
 def _nan2None(obj):
-
-
-
     if isinstance(obj, dict):
         return {k: _nan2None(v) for k, v in obj.items()}
     elif isinstance(obj, list):
@@ -53,4 +51,10 @@ class _NanConverter(JSONEncoder):
         return super().iterencode(obj, *args, **kwargs)
 
 
-json_dumps_fn = partial(dumps, cls=_NanConverter)
\ No newline at end of file
+json_dumps_fn = partial(dumps, cls=_NanConverter)
+
+
+def data2html_img_src(data:bytes):
+    b64=base64.b64encode(data).decode('utf8')
+    value = f'data:image/png;base64,{b64}'
+    return value
\ No newline at end of file
